@@ -83,6 +83,12 @@ def classification_report(y_true, y_pred):
                       'True': 1 if y in y_true else 0,
                       'Pred': 1 if y in y_pred else 0,
                       })
+    if len(serie) == 0:
+        serie.append({'Code': None,
+                      'Name': None,
+                      'True': None,
+                      'Pred': None,
+                      })
     return pd.DataFrame.from_records(serie)
 
 
