@@ -4,7 +4,7 @@ from pathlib import Path
 from pymultirole_plugins.v1.schema import Document
 from starlette.responses import Response
 
-from pyformatters_afp_quality.afp_quality import AFPQualityFormatter, AFPQualityParameters, OutputFormat
+from pyformatters_afp_quality.afp_quality import AFPQualityFormatter, AFPQualityParameters
 
 
 def test_xlsx():
